# 🎒 {{cookiecutter.challenge.slug}} challenge pack
Thank you for hosting your challenge on Grand-Challenge.org. We appreciate it!

## Content

This Challenge Pack is a collection of challenge-tailored examples to help you on your
way to hosting your {{cookiecutter.challenge.slug}} challenge.

It contains the following:
* ️🦾 An example script to _automate uploading_ data to an archive
* 🦿 An example _submission algorithm_ that can be uploaded to run as a submission in a challenge-phase
* 🧮 An example _evaluation method_ that evaluates algorithm submissions and generates performance
  metrics for ranking

The examples are categorized per phase.

Please note that this is a supplementary pack to the [documentation](https://grand-challenge.org/documentation/challenges/).
If the documentation does not answer your question, feel free to reach out to us at
[support@grand-challenge.org](mailto:support@grandchallenge.org).

## Archives
Challenge phases pull their data from archives to test submissions on.

Your challenge has the following archives:

{% for phase in cookiecutter.challenge.phases -%}
  * {{phase.archive.url}}
{% endfor %}
